% Returns reflection cross-section corresponding to vertical-incidence 
% reflections from one boundary.
% Reflection amplitudes shoud be given in the third column of matrix 'layer' 
%
% Input parameters:
%   SR - source/receiver positions (can be an array)
%   layer - matrix of boundary points returned by picklayer()
%   velocity - harmonic average of wave velocities above the boundary
%         This should be a column of the same vertical dimension as 'layer'
%   refl - Reflection amplitudes from this boundary
%         This should be a column of the same vertical dimension as 'layer'
%         If this column is absent, reflection amplitudes are taken equal 0.1

%   Common model parameters are provided by 'global' 

% Returns:
%   section - the resulting seismic section. n-th columns of the
%         matrix contains reflection amplitudes at n-th receiver
%         at times sampled in array 'time'

function [section] = reflection_VI(SR,layer,velocity,refl)

global  time dt
global  line_length depth spacing

  nt = length(time);      % number of time samples
  
  % first create zero traces for each source/receiver and time
  
  section = zeros(nt,length(SR));
  
  % select the range of SR above the reflector
   
  ind = find(SR>=layer(1,1) & SR<=layer(end,1));
  SR = SR(ind);
 
  % determine slowness (row)
  
  slowness = (velocity.^(-1))';
  refl = refl';     
  
  xl = layer(:,1)'; 
  
%  ind
%[ xp yp]

  % add reflections from each reflection point to the section
  
  for is = 1:length(ind)
   
      i = ind(is);     % number of record into which we will add waveform
      x = SR(i);       % coordinate
      
      % mean slowness at this point:
     
      sl = interp1(xl,slowness,x);
       
      % reflection coefficient at this point:
     
      r = interp1(xl,refl,x);

      % two-way travel time:
      
      t = interp1(xl,layer(:,2),x)*2*sl;
           
      % add wavelet at reflection time t
  
      section(:,i) =  section(:,i) + wavelet(r,t,time)';
      
  end     % for is
  
  % finally, scale the whole section so that its peak amplitude equals 
  % receiver spacing (for plotting)
  
  section = section *(spacing/ max(max(section)));
  
end
